@@ -231,7 +231,7 @@ pub fn encrypt(data: Vec<u8>, key: Vec<u8>) -> Vec<Vec<u8>> {
     } else if data.len() < 8 {
         let mut new_data = data.clone().to_vec();
         for i in data.len()..=8 {
-            new_data.push("■".as_bytes()[0]);
+            new_data.extend_from_slice("■".as_bytes());
         }
         re.push(en(&new_data, &key));
     } else if data.len() > 8 {
